@@ -143,5 +143,5 @@ class PVML(DataSourceOutputML):
         if not self.normalized:
             # Expand capacity to the same timesteps for broadcasting
             capacity = np.expand_dims(self.pv_capacity, axis=1)
-            self.pv_yield = self.pv_yield - capacity
+            self.pv_yield = self.pv_yield / capacity
             self.normalized = True
